==> telegram_payment_bot-0.2.0.tar.gz: telegram_payment_bot-0.2.0/telegram_payment_bot/command_base.py <==
# Copyright (c) 2021 Emanuele Bellocchia
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

#
# Imports
#
import pyrogram
from abc import ABC, abstractmethod
from pyrogram.errors import RPCError
from typing import Any
from telegram_payment_bot.command_data import CommandData
from telegram_payment_bot.config import Config
from telegram_payment_bot.logger import Logger
from telegram_payment_bot.message_sender import MessageSender
from telegram_payment_bot.special_users_list import AuthorizedUsersList
from telegram_payment_bot.helpers import ChatHelper, UserHelper
from telegram_payment_bot.translation_loader import TranslationLoader


#
# Classes
#

#
# Generic command base class
#
class CommandBase(ABC):
    # Constructor
    def __init__(self,
                 client: pyrogram.Client,
                 config: Config,
                 logger: Logger,
                 translator: TranslationLoader) -> None:
        self.client = client
        self.config = config
        self.logger = logger
        self.translator = translator
        self.message = None
        # Helper classes
        self.cmd_data = None
        self.message_sender = MessageSender(client, config, logger)

    # Set message
    def SetMessage(self,
                   message: pyrogram.types.Message) -> None:
        self.message = message
        self.cmd_data = CommandData(message)

    # Execute command
    def Execute(self,
                **kwargs: Any) -> None:
        # Log command
        self.__LogCommand()

        # Check if user is authorized
        if self._IsUserAuthorized():
            # Try to execute command
            try:
                self._ExecuteCommand(**kwargs)
            except RPCError:
                self._SendMessage(self.translator.GetSentence("GENERIC_ERR"))
                self.logger.GetLogger().exception("An error occurred while executing command %s" % self.cmd_data.Name())
        else:
            if self._IsPrivateChat():
                self._SendMessage(self.translator.GetSentence("AUTH_ONLY_ERR"))

            self.logger.GetLogger().warning("User %s tried to execute the command but it's not authorized" %
                                            UserHelper.GetNameOrId(self.cmd_data.User()))

    # Send message
    def _SendMessage(self,
                     msg: str) -> None:
        if self._IsQuietMode():
            self.message_sender.SendMessage(self.cmd_data.User(), msg)
        else:
            self.message_sender.SendMessage(self.cmd_data.Chat(), msg)

    # Send message to authorized users
    def _SendMessageToAuthUsers(self,
                                msg: str) -> None:
        self.message_sender.SendMessageToAuthUsers(self.cmd_data.Chat(), msg)

    # Get if user is authorized
    def _IsUserAuthorized(self) -> bool:
        return AuthorizedUsersList(self.config).IsUserPresent(self.cmd_data.User())

    # Get if chat is private
    def _IsPrivateChat(self) -> bool:
        return ChatHelper.IsPrivateChat(self.cmd_data.Chat(), self.cmd_data.User())

    # Get if quiet mode
    def _IsQuietMode(self) -> bool:
        return self.cmd_data.Params().IsLast("q") or self.cmd_data.Params().IsLast("quiet")

    # Generate new invite link
    def _NewInviteLink(self) -> None:
        # Generate new invite link
        invite_link = self.client.export_chat_invite_link(self.cmd_data.Chat().id)
        # Send messages
        self._SendMessage(self.translator.GetSentence("INVITE_LINK_ALL_CMD"))
        self._SendMessageToAuthUsers(self.translator.GetSentence("INVITE_LINK_AUTH_CMD") %
                                     (ChatHelper.GetTitle(self.cmd_data.Chat()), invite_link))

    # Log command
    def __LogCommand(self) -> None:
        # Log
        self.logger.GetLogger().info("Command: %s" % self.cmd_data.Name())
        self.logger.GetLogger().info("Executed by user: %s" % UserHelper.GetNameOrId(self.cmd_data.User()))
        self.logger.GetLogger().debug("Received message: %s" % self.message)

    # Execute command - Abstract method
    @abstractmethod
    def _ExecuteCommand(self,
                        **kwargs: Any) -> None:
        pass

==> telegram_payment_bot-0.3.0.tar.gz: telegram_payment_bot-0.3.0/telegram_payment_bot/command_base.py <==
# Copyright (c) 2021 Emanuele Bellocchia
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

#
# Imports
#
import pyrogram
from abc import ABC, abstractmethod
from pyrogram.errors import RPCError
from typing import Any
from telegram_payment_bot.command_data import CommandData
from telegram_payment_bot.config import Config
from telegram_payment_bot.logger import Logger
from telegram_payment_bot.message_sender import MessageSender
from telegram_payment_bot.special_users_list import AuthorizedUsersList
from telegram_payment_bot.helpers import ChatHelper, UserHelper
from telegram_payment_bot.translation_loader import TranslationLoader


#
# Classes
#

#
# Generic command base class
#
class CommandBase(ABC):
    # Constructor
    def __init__(self,
                 client: pyrogram.Client,
                 config: Config,
                 logger: Logger,
                 translator: TranslationLoader) -> None:
        self.client = client
        self.config = config
        self.logger = logger
        self.translator = translator
        self.message = None
        self.cmd_data = None
        self.message_sender = MessageSender(client, config, logger)

    # Execute command
    def Execute(self,
                message: pyrogram.types.Message,
                **kwargs: Any) -> None:
        # Set members
        self.message = message
        self.cmd_data = CommandData(message)

        # Log command
        self.__LogCommand()

        # Check if user is authorized
        if self._IsUserAuthorized():
            # Try to execute command
            try:
                self._ExecuteCommand(**kwargs)
            except RPCError:
                self._SendMessage(self.translator.GetSentence("GENERIC_ERR_MSG"))
                self.logger.GetLogger().exception(
                    f"An error occurred while executing command {self.cmd_data.Name()}"
                )
        else:
            if self._IsPrivateChat():
                self._SendMessage(self.translator.GetSentence("AUTH_ONLY_ERR_MSG"))

            self.logger.GetLogger().warning(
                f"User {UserHelper.GetNameOrId(self.cmd_data.User())} tried to execute the command but it's not authorized"
            )

    # Send message
    def _SendMessage(self,
                     msg: str) -> None:
        if self._IsQuietMode():
            self.message_sender.SendMessage(self.cmd_data.User(), msg)
        else:
            self.message_sender.SendMessage(self.cmd_data.Chat(), msg)

    # Send message to authorized users
    def _SendMessageToAuthUsers(self,
                                msg: str) -> None:
        self.message_sender.SendMessageToAuthUsers(self.cmd_data.Chat(), msg)

    # Get if user is authorized
    def _IsUserAuthorized(self) -> bool:
        return AuthorizedUsersList(self.config).IsUserPresent(self.cmd_data.User())

    # Get if chat is private
    def _IsPrivateChat(self) -> bool:
        return ChatHelper.IsPrivateChat(self.cmd_data.Chat(), self.cmd_data.User())

    # Get if quiet mode
    def _IsQuietMode(self) -> bool:
        return self.cmd_data.Params().IsLast("q") or self.cmd_data.Params().IsLast("quiet")

    # Generate new invite link
    def _NewInviteLink(self) -> None:
        # Generate new invite link
        invite_link = self.client.export_chat_invite_link(self.cmd_data.Chat().id)
        # Send messages
        self._SendMessage(self.translator.GetSentence("INVITE_LINK_ALL_CMD"))
        self._SendMessageToAuthUsers(
            self.translator.GetSentence("INVITE_LINK_AUTH_CMD",
                                        chat_title=ChatHelper.GetTitle(self.cmd_data.Chat()),
                                        invite_link=invite_link)
        )

    # Log command
    def __LogCommand(self) -> None:
        self.logger.GetLogger().info(f"Command: {self.cmd_data.Name()}")
        self.logger.GetLogger().info(f"Executed by user: {UserHelper.GetNameOrId(self.cmd_data.User())}")
        self.logger.GetLogger().debug(f"Received message: {self.message}")

    # Execute command - Abstract method
    @abstractmethod
    def _ExecuteCommand(self,
                        **kwargs: Any) -> None:
        pass
